pilas.habilidades.Arrastrable

Package pilas :: Module habilidades :: Class Arrastrable |
[hide private]
[frames] | no frames]

# Class Arrastrable

source code

    object --+
             |
     Habilidad --+
                 |
                Arrastrable

Hace que un objeto se pueda arrastrar con el puntero del mouse.

Cuando comienza a mover al actor se llama al metodo ''comienza_a_arrastrar'' y cuando termina llama a ''termina_de_arrastrar''. Estos nombres de metodos se llaman para que puedas personalizar estos eventos, dado que puedes usar polimorfismo para redefinir el comportamiento de estos dos metodos. Observa un ejemplo de esto en el ejemplo ``pilas.ejemplos.Piezas``.

Instance Methods | [hide private]
__init__(self, receptor) x.__init__(...) initializes x; see help(type(x)) for signature | source code
cuando_intenta_arrastrar(self, evento) Intenta mover el objeto con el mouse cuando se pulsa sobre el. | source code
cuando_arrastra(self, evento) Arrastra el actor a la posicion indicada por el puntero del mouse. | source code
cuando_termina_de_arrastrar(self, evento) Suelta al actor porque se ha soltado el botón del mouse. | source code
comienza_a_arrastrar(self) | source code
termina_de_arrastrar(self) | source code
_el_receptor_tiene_fisica(self) | source code
Inherited from `Habilidad`: `actualizar`, `eliminar` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, receptor) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)